@@ -51,10 +51,16 @@ G_BEGIN_DECLS
 #define EMPATHY_PREFS_SOUNDS_CONTACT_LOGIN         "sounds-contact-login"
 #define EMPATHY_PREFS_SOUNDS_CONTACT_LOGOUT        "sounds-contact-logout"
 
+#define EMPATHY_PREFS_CALL_SCHEMA EMPATHY_PREFS_SCHEMA ".call"
+#define EMPATHY_PREFS_CALL_SOUND_VOLUME            "volume"
+#define EMPATHY_PREFS_CALL_CAMERA_DEVICE           "camera-device"
+#define EMPATHY_PREFS_CALL_ECHO_CANCELLATION       "echo-cancellation"
+
 #define EMPATHY_PREFS_CHAT_SCHEMA EMPATHY_PREFS_SCHEMA ".conversation"
 #define EMPATHY_PREFS_CHAT_SHOW_SMILEYS            "graphical-smileys"
 #define EMPATHY_PREFS_CHAT_SHOW_CONTACTS_IN_ROOMS  "show-contacts-in-rooms"
 #define EMPATHY_PREFS_CHAT_THEME                   "theme"
+#define EMPATHY_PREFS_CHAT_THEME_VARIANT           "theme-variant"
 #define EMPATHY_PREFS_CHAT_ADIUM_PATH              "adium-path"
 #define EMPATHY_PREFS_CHAT_SPELL_CHECKER_LANGUAGES "spell-checker-languages"
 #define EMPATHY_PREFS_CHAT_SPELL_CHECKER_ENABLED   "spell-checker-enabled"
