@@ -162,34 +162,43 @@ individual_notify_personas_cb (FolksIndividual *individual,
 
 static void
 aggregator_individuals_changed_cb (FolksIndividualAggregator *aggregator,
-    GList *added,
-    GList *removed,
+    GeeSet *added,
+    GeeSet *removed,
     const char *message,
     FolksPersona *actor,
     guint reason,
     EmpathyIndividualManager *self)
 {
   EmpathyIndividualManagerPriv *priv = GET_PRIV (self);
-  GList *l, *added_filtered = NULL;
+  GeeIterator *iter;
+  GList *added_filtered = NULL, *removed_list = NULL;
 
   /* Handle the removals first, as one of the added Individuals might have the
    * same ID as one of the removed Individuals (due to linking). */
-  for (l = removed; l; l = l->next)
+  iter = gee_iterable_iterator (GEE_ITERABLE (removed));
+  while (gee_iterator_next (iter))
     {
-      FolksIndividual *ind = FOLKS_INDIVIDUAL (l->data);
+      FolksIndividual *ind = gee_iterator_get (iter);
 
       g_signal_handlers_disconnect_by_func (ind,
           individual_notify_personas_cb, self);
 
       if (g_hash_table_lookup (priv->individuals,
           folks_individual_get_id (ind)) != NULL)
-        remove_individual (self, ind);
+        {
+          remove_individual (self, ind);
+          removed_list = g_list_prepend (removed_list, ind);
+        }
+
+      g_clear_object (&ind);
     }
+  g_clear_object (&iter);
 
   /* Filter the individuals for ones which contain EmpathyContacts */
-  for (l = added; l; l = l->next)
+  iter = gee_iterable_iterator (GEE_ITERABLE (added));
+  while (gee_iterator_next (iter))
     {
-      FolksIndividual *ind = FOLKS_INDIVIDUAL (l->data);
+      FolksIndividual *ind = gee_iterator_get (iter);
 
       g_signal_connect (ind, "notify::personas",
           G_CALLBACK (individual_notify_personas_cb), self);
@@ -199,7 +208,10 @@ aggregator_individuals_changed_cb (FolksIndividualAggregator *aggregator,
           add_individual (self, ind);
           added_filtered = g_list_prepend (added_filtered, ind);
         }
+
+      g_clear_object (&ind);
     }
+  g_clear_object (&iter);
 
   /* Bail if we have no individuals left */
   if (added_filtered == NULL && removed == NULL)
@@ -208,11 +220,12 @@ aggregator_individuals_changed_cb (FolksIndividualAggregator *aggregator,
   added_filtered = g_list_reverse (added_filtered);
 
   g_signal_emit (self, signals[MEMBERS_CHANGED], 0, message,
-      added_filtered, removed,
+      added_filtered, removed_list,
       tp_channel_group_change_reason_from_folks_groups_change_reason (reason),
       TRUE);
 
   g_list_free (added_filtered);
+  g_list_free (removed_list);
 }
 
 static void
@@ -388,7 +401,8 @@ empathy_individual_manager_add_from_contact (EmpathyIndividualManager *self,
   FolksBackendStore *backend_store;
   FolksBackend *backend;
   FolksPersonaStore *persona_store;
-  GHashTable* details, *persona_stores;
+  GHashTable* details;
+  GeeMap *persona_stores;
   TpAccount *account;
   const gchar *store_id;
 
@@ -420,7 +434,7 @@ empathy_individual_manager_add_from_contact (EmpathyIndividualManager *self,
     }
 
   persona_stores = folks_backend_get_persona_stores (backend);
-  persona_store = g_hash_table_lookup (persona_stores, store_id);
+  persona_store = gee_map_get (persona_stores, store_id);
 
   if (persona_store == NULL)
     {
@@ -438,6 +452,7 @@ empathy_individual_manager_add_from_contact (EmpathyIndividualManager *self,
       aggregator_add_persona_from_details_cb, contact);
 
   g_hash_table_destroy (details);
+  g_object_unref (persona_store);
 
 finish:
   tp_clear_object (&backend);
@@ -500,32 +515,36 @@ gboolean
 empathy_individual_manager_supports_blocking (EmpathyIndividualManager *self,
     FolksIndividual *individual)
 {
-  GList *personas, *l;
+  GeeSet *personas;
+  GeeIterator *iter;
+  gboolean retval = FALSE;
 
   g_return_val_if_fail (EMPATHY_IS_INDIVIDUAL_MANAGER (self), FALSE);
 
   personas = folks_individual_get_personas (individual);
-
-  for (l = personas; l != NULL; l = l->next)
+  iter = gee_iterable_iterator (GEE_ITERABLE (personas));
+  while (!retval && gee_iterator_next (iter))
     {
-      TpfPersona *persona = l->data;
+      TpfPersona *persona = gee_iterator_get (iter);
       TpConnection *conn;
       EmpathyContactManager *manager;
 
-      if (!TPF_IS_PERSONA (persona))
-        continue;
+      if (TPF_IS_PERSONA (persona))
+        {
+          conn = tp_contact_get_connection (tpf_persona_get_contact (persona));
+          manager = empathy_contact_manager_dup_singleton ();
 
-      conn = tp_contact_get_connection (tpf_persona_get_contact (persona));
-      manager = empathy_contact_manager_dup_singleton ();
+          if (empathy_contact_manager_get_flags_for_connection (manager, conn) &
+              EMPATHY_CONTACT_LIST_CAN_BLOCK)
+            retval = TRUE;
 
-      if (empathy_contact_manager_get_flags_for_connection (manager, conn) &
-          EMPATHY_CONTACT_LIST_CAN_BLOCK)
-        return TRUE;
-
-      g_object_unref (manager);
+          g_object_unref (manager);
+        }
+      g_clear_object (&persona);
     }
+  g_clear_object (&iter);
 
-  return FALSE;
+  return retval;
 }
 
 void
@@ -534,37 +553,40 @@ empathy_individual_manager_set_blocked (EmpathyIndividualManager *self,
     gboolean blocked,
     gboolean abusive)
 {
-  GList *personas, *l;
+  GeeSet *personas;
+  GeeIterator *iter;
 
   g_return_if_fail (EMPATHY_IS_INDIVIDUAL_MANAGER (self));
 
   personas = folks_individual_get_personas (individual);
-
-  for (l = personas; l != NULL; l = l->next)
+  iter = gee_iterable_iterator (GEE_ITERABLE (personas));
+  while (gee_iterator_next (iter))
     {
-      TpfPersona *persona = l->data;
+      TpfPersona *persona = gee_iterator_get (iter);
       EmpathyContact *contact;
       EmpathyContactManager *manager;
       EmpathyContactListFlags flags;
 
-      if (!TPF_IS_PERSONA (persona))
-        continue;
+      if (TPF_IS_PERSONA (persona))
+        {
+          contact = empathy_contact_dup_from_tp_contact (
+              tpf_persona_get_contact (persona));
+          empathy_contact_set_persona (contact, FOLKS_PERSONA (persona));
+          manager = empathy_contact_manager_dup_singleton ();
+          flags = empathy_contact_manager_get_flags_for_connection (manager,
+              empathy_contact_get_connection (contact));
 
-      contact = empathy_contact_dup_from_tp_contact (
-          tpf_persona_get_contact (persona));
-      empathy_contact_set_persona (contact, FOLKS_PERSONA (persona));
-      manager = empathy_contact_manager_dup_singleton ();
-      flags = empathy_contact_manager_get_flags_for_connection (manager,
-          empathy_contact_get_connection (contact));
+          if (flags & EMPATHY_CONTACT_LIST_CAN_BLOCK)
+            empathy_contact_list_set_blocked (
+                EMPATHY_CONTACT_LIST (manager),
+                contact, blocked, abusive);
 
-      if (flags & EMPATHY_CONTACT_LIST_CAN_BLOCK)
-        empathy_contact_list_set_blocked (
-            EMPATHY_CONTACT_LIST (manager),
-            contact, blocked, abusive);
-
-      g_object_unref (manager);
-      g_object_unref (contact);
+          g_object_unref (manager);
+          g_object_unref (contact);
+        }
+      g_clear_object (&persona);
     }
+  g_clear_object (&iter);
 }
 
 static void
@@ -629,7 +651,7 @@ link_personas_cb (FolksIndividualAggregator *aggregator,
 
 void
 empathy_individual_manager_link_personas (EmpathyIndividualManager *self,
-    GList *personas)
+    GeeSet *personas)
 {
   EmpathyIndividualManagerPriv *priv;
 
@@ -638,7 +660,8 @@ empathy_individual_manager_link_personas (EmpathyIndividualManager *self,
 
   priv = GET_PRIV (self);
 
-  DEBUG ("Linking %u personas", g_list_length (personas));
+  DEBUG ("Linking %u personas",
+      gee_collection_get_size (GEE_COLLECTION (personas)));
 
   folks_individual_aggregator_link_personas (priv->aggregator, personas,
       (GAsyncReadyCallback) link_personas_cb, NULL);
