@@ -93,20 +93,7 @@ GPtrArray *    empathy_tp_chat_get_properties       (EmpathyTpChat      *chat);
 const GList *  empathy_tp_chat_get_pending_messages (EmpathyTpChat *chat);
 void           empathy_tp_chat_acknowledge_message (EmpathyTpChat *chat,
 						     EmpathyMessage *message);
-void           empathy_tp_chat_acknowledge_messages (EmpathyTpChat *chat,
-						     const GSList *messages);
-void           empathy_tp_chat_acknowledge_all_messages (EmpathyTpChat *chat);
 
-gboolean       empathy_tp_chat_password_needed      (EmpathyTpChat *chat);
-
-void           empathy_tp_chat_provide_password_async (EmpathyTpChat *chat,
-						       const gchar *password,
-						       GAsyncReadyCallback callback,
-						       gpointer user_data);
-
-gboolean       empathy_tp_chat_provide_password_finish (EmpathyTpChat *chat,
-							GAsyncResult *result,
-							GError **error);
 gboolean       empathy_tp_chat_can_add_contact (EmpathyTpChat *self);
 
 void           empathy_tp_chat_leave                (EmpathyTpChat      *chat,
